@@ -2,6 +2,9 @@ import json
 from datetime import datetime, timedelta
 import pytest
 import random
+from sys import version_info
+import uuid
+
 import tests
 from turing.ensembler import PyFuncEnsembler
 import turing.generated.models
@@ -16,7 +19,6 @@ from turing.router.config.enricher import Enricher
 from turing.router.config.router_ensembler_config import DockerRouterEnsemblerConfig
 from turing.router.config.common.env_var import EnvVar
 from turing.router.config.experiment_config import ExperimentConfig
-import uuid
 from tests.fixtures.mlflow import mock_mlflow
 from tests.fixtures.gcs import mock_gcs
 
@@ -115,7 +117,8 @@ def pyfunc_ensembler(project, ensembler_name, experiment_id, run_id, artifact_ur
         mlflow_run_id=run_id,
         artifact_uri=artifact_uri,
         created_at=datetime.now(),
-        updated_at=datetime.now()
+        updated_at=datetime.now(),
+        python_version=f"{version_info.major}.{version_info.minor}.*"
     )
 
 
@@ -333,19 +336,29 @@ def generic_ensembler_docker_config(generic_resource_request, generic_env_var):
     )
 
 
-@pytest.fixture(params=["standard", "docker"])
-def ensembler(request, generic_ensembler_standard_config, generic_ensembler_docker_config):
+@pytest.fixture
+def generic_ensembler_pyfunc_config(generic_resource_request, generic_env_var):
+    return turing.generated.models.EnsemblerPyfuncConfig(
+        project_id=77,
+        ensembler_id=11,
+        resource_request=generic_resource_request,
+        timeout="500ms",
+        env=[generic_env_var]
+    )
+
+
+@pytest.fixture(params=["standard", "docker", "pyfunc"])
+def ensembler(request, generic_ensembler_standard_config, generic_ensembler_docker_config, generic_ensembler_pyfunc_config):
     ensembler_type = request.param
     return turing.generated.models.RouterEnsemblerConfig(
-        id=1,
         type=ensembler_type,
         standard_config=generic_ensembler_standard_config,
         docker_config=generic_ensembler_docker_config,
+        pyfunc_config=generic_ensembler_pyfunc_config,
         created_at=datetime.now() + timedelta(seconds=10),
         updated_at=datetime.now() + timedelta(seconds=10)
     )
 
-
 @pytest.fixture
 def generic_standard_router_ensembler_config(generic_ensembler_standard_config):
     return turing.generated.models.RouterEnsemblerConfig(
@@ -362,6 +375,14 @@ def generic_docker_router_ensembler_config(generic_ensembler_docker_config):
     )
 
 
+@pytest.fixture
+def generic_pyfunc_router_ensembler_config(generic_ensembler_pyfunc_config):
+    return turing.generated.models.RouterEnsemblerConfig(
+        type="pyfunc",
+        pyfunc_config=generic_ensembler_pyfunc_config
+    )
+
+
 @pytest.fixture
 def generic_enricher(generic_resource_request, generic_env_var):
     return turing.generated.models.Enricher(
@@ -426,14 +447,16 @@ def generic_router_version(
         id=2,
         created_at=datetime.now() + timedelta(seconds=20),
         updated_at=datetime.now() + timedelta(seconds=20),
-        router=None,
+        router=turing.generated.models.Router(
+            environment_name="test_env",
+            name="test_router"
+        ),
         version=1,
         status=generic_router_version_status,
         error="NONE",
         image="test.io/just-a-test/turing-router:0.0.0-build.0",
         routes=[generic_route for _ in range(2)],
-        default_route="http://models.internal/default",
-        default_route_id="control",
+        default_route_id=generic_route.id,
         rules=[generic_traffic_rule for _ in range(2)],
         experiment_engine=experiment_config,
         resource_request=generic_resource_request,
@@ -463,9 +486,9 @@ def generic_router_config():
             )
         ],
         rules=None,
-        default_route_id="test",
+        default_route_id="model-a",
         experiment_engine=ExperimentConfig(
-            type="xp",
+            type="test-exp",
             config={
                 'variables':
                         [
@@ -508,7 +531,6 @@ def generic_router_config():
             ]
         ),
         ensembler=DockerRouterEnsemblerConfig(
-            id=1,
             image="test.io/just-a-test/turing-ensembler:0.0.0-build.0",
             resource_request=ResourceRequest(
                 min_replica=1,
@@ -559,7 +581,7 @@ def generic_routers(project, num_routers, generic_router_status, generic_router_
 
 @pytest.fixture
 def generic_events():
-    return turing.generated.models.InlineResponse2002(
+    return turing.generated.models.RouterEvents(
         events=[
             turing.generated.models.Event(
                 created_at=datetime.now(),
