@@ -1,3 +1,4 @@
+import deprecation
 import inspect
 from typing import List, Dict, Union
 from collections import Counter
@@ -10,7 +11,7 @@ from turing.router.config.traffic_rule import TrafficRule
 from turing.router.config.resource_request import ResourceRequest
 from turing.router.config.log_config import LogConfig, ResultLoggerType
 from turing.router.config.enricher import Enricher
-from turing.router.config.router_ensembler_config import RouterEnsemblerConfig
+from turing.router.config.router_ensembler_config import RouterEnsemblerConfig, NopRouterEnsemblerConfig, StandardRouterEnsemblerConfig
 from turing.router.config.experiment_config import ExperimentConfig
 
 
@@ -73,6 +74,7 @@ class RouterConfig:
         self.timeout = timeout
         self.log_config = log_config
         self.enricher = enricher
+        # Init ensembler after the default route has been initialized
         self.ensembler = ensembler
 
     @property
@@ -124,10 +126,14 @@ class RouterConfig:
             self._rules = rules
 
     @property
+    @deprecation.deprecated(deprecated_in="0.4.0",
+        details="Please use the ensembler properties to configure the final / fallback route.")
     def default_route_id(self) -> str:
         return self._default_route_id
 
     @default_route_id.setter
+    @deprecation.deprecated(deprecated_in="0.4.0",
+        details="Please use the ensembler properties to configure the final / fallback route.")
     def default_route_id(self, default_route_id: str):
         self._default_route_id = default_route_id
 
@@ -197,9 +203,15 @@ class RouterConfig:
 
     @ensembler.setter
     def ensembler(self, ensembler: Union[RouterEnsemblerConfig, Dict]):
-        if isinstance(ensembler, RouterEnsemblerConfig):
+        if ensembler is None:
+            # Init nop ensembler config if ensembler is not set
+            self._ensembler = NopRouterEnsemblerConfig(final_response_route_id=self.default_route_id)
+        elif isinstance(ensembler, RouterEnsemblerConfig):
             self._ensembler = ensembler
         elif isinstance(ensembler, dict):
+            # Set fallback_response_route_id into standard ensembler config
+            if ensembler["type"] == "standard" and "fallback_response_route_id" not in ensembler["standard_config"]:
+                ensembler["standard_config"]["fallback_response_route_id"] = self.default_route_id
             self._ensembler = RouterEnsemblerConfig(**ensembler)
         else:
             self._ensembler = ensembler
@@ -207,6 +219,11 @@ class RouterConfig:
     def to_open_api(self) -> OpenApiModel:
         kwargs = {}
         self._verify_no_duplicate_routes()
+        
+        # Get default route id if exists
+        default_route_id = self._get_default_route_id()
+        if default_route_id is not None:
+            kwargs['default_route_id'] = default_route_id
 
         if self.rules is not None:
             kwargs['rules'] = [rule.to_open_api() for rule in self.rules]
@@ -216,13 +233,15 @@ class RouterConfig:
             kwargs['enricher'] = self.enricher.to_open_api()
         if self.ensembler is not None:
             kwargs['ensembler'] = self.ensembler.to_open_api()
+            if kwargs['ensembler'] is None:
+                # The Turing API does not handle an ensembler type "nop" - it must be left unset.
+                del kwargs['ensembler']
 
         return turing.generated.models.RouterConfig(
             environment_name=self.environment_name,
             name=self.name,
             config=turing.generated.models.RouterVersionConfig(
                 routes=[route.to_open_api() for route in self.routes],
-                default_route_id=self.default_route_id,
                 experiment_engine=self.experiment_engine.to_open_api(),
                 timeout=self.timeout,
                 log_config=self.log_config.to_open_api(),
@@ -230,6 +249,26 @@ class RouterConfig:
             )
         )
 
+    def _get_default_route_id(self):
+        default_route_id = self.default_route_id
+        # If nop config is set, use the final_response_route_id as the default
+        if isinstance(self.ensembler, NopRouterEnsemblerConfig):
+            default_route_id = self.ensembler.final_response_route_id
+        # Or, if standard config is set, use the fallback_response_route_id as the default
+        elif isinstance(self.ensembler, StandardRouterEnsemblerConfig):
+            default_route_id = self.ensembler.fallback_response_route_id
+        if default_route_id is not None:
+            self._verify_default_route_exists(default_route_id)
+        return default_route_id
+
+    def _verify_default_route_exists(self, default_route_id: str):
+        for route in self.routes:
+            if route.id == default_route_id:
+                return
+        raise turing.router.config.route.InvalidRouteException(
+                f"Default route id {default_route_id} is not registered in the routes."
+            )
+
     def _verify_no_duplicate_routes(self):
         route_id_counter = Counter(route.id for route in self.routes)
         most_common_route_id, max_frequency = route_id_counter.most_common(n=1)[0]
